from PyQt5.QtXmlPatterns import (
    QAbstractMessageHandler,
    QAbstractUriResolver,
    QAbstractXmlNodeModel,
    QAbstractXmlReceiver,
    QSimpleXmlNodeModel,
    QSourceLocation,
    QXmlFormatter,
    QXmlItem,
    QXmlName,
    QXmlNamePool,
    QXmlNodeModelIndex,
    QXmlQuery,
    QXmlResultItems,
    QXmlSchema,
    QXmlSchemaValidator,
    QXmlSerializer,
)